Contributors
============

* Alexis Metaireau <alexis@mozilla.com>
* Andy McKay <amckay@mozilla.com>
* Dan Phrawzty <phrawzty+github@gmail.com>
* Fil <fil@rezo.net>
* Greeshma <https://github.com/greeshmab>
* Mathieu Agopian <mathieu@agopian.info>
* Mathieu Leplatre <mathieu@mozilla.com>
* Nicolas Perriault <nperriault@mozilla.com>
* Niraj <https://github.com/niraj8>
* Rémy Hubscher <rhubscher@mozilla.com>
* Shweta Oak <oakshweta11@gmail.com>
* Sofia Utsch <sofia.utsch@gmail.com>
* Tarek Ziade <tarek@mozilla.com>
